@@ -9,16 +9,14 @@ var version string
 
 func main() {
 	arguments, err := parseArguments(os.Args[1:])
-	if err == NoCommand {
-		if arguments.isHelp {
-			help()
-			os.Exit(0)
-		}
+	if arguments.isHelp {
+		help()
+		os.Exit(0)
+	}
 
-		if arguments.isVersion {
-			fmt.Printf("viddy version: %s\n", version)
-			os.Exit(0)
-		}
+	if arguments.isVersion {
+		fmt.Printf("viddy version: %s\n", version)
+		os.Exit(0)
 	}
 
 	if err != nil {
@@ -26,6 +24,7 @@ func main() {
 		os.Exit(1)
 	}
 
+
 	var mode ViddyIntervalMode
 	switch {
 	case arguments.isPrecise:
